@@ -1,11 +1,6 @@
 import unittest
-from mock import MagicMock
 
-from insider.port_mapper import find_available_port
-from insider.port_mapper import PortMapper
-from insider.config import Port, Service
-
-from helpers import get_port_config
+from syncloud.insider.config import Service
 from test.helpers import get_service_config
 
 
